@@ -35,9 +35,9 @@ sub download_youtube {
             for my $fmt ( sort keys %{$info->{$ex}{$video_id}{file_name}} ) {
                 my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
                 try {
-                    unlink encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!" if -f encode_fs( $file_name ) && $opt->{overwrite};
+                    unlink encode_fs( $opt, $file_name ) or die encode_fs( $opt, $file_name ) . " $!" if -f encode_fs( $opt, $file_name ) && $opt->{overwrite};
                     _download_video( $opt, $info, $ex, $video_id, $fmt, $nr );
-                    timestamp_to_upload_date( $info, $ex, $video_id, $file_name ) if $opt->{modify_timestamp};
+                    timestamp_to_upload_date( $opt, $info, $ex, $video_id, $file_name ) if $opt->{modify_timestamp};
                 }
                 catch {
                     say "$video_id - ", check_mapping_stdout( $opt, $_ );
@@ -72,7 +72,7 @@ sub _download_video {
     my $try = 1;
 
     RETRY: while ( 1 ) {
-        $p->{size}      = -s encode_fs( $file_name ) // 0;
+        $p->{size}      = -s encode_fs( $opt, $file_name ) // 0;
         $p->{starttime} = gettimeofday;
         my $retries = sprintf "%*s/%s", length $opt->{retries}, $try, $opt->{retries};
         if ( $try > 1 ) {
@@ -86,7 +86,7 @@ sub _download_video {
         if ( ! $p->{size} ) {
             my $at = '';
             printf _p_fmt( $opt, "start" ), $video_count, $retries, $at;
-            open my $fh, '>:raw', encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!";
+            open my $fh, '>:raw', encode_fs( $opt, $file_name ) or die encode_fs( $opt, $file_name ) . " $!";
             _log_info( $opt, $info, $ex, $video_id, $fmt ) if $opt->{log_info};
             $res = $ua->get(
                 $video_url,
@@ -97,7 +97,7 @@ sub _download_video {
         elsif ( $p->{size} ) {
             my $at = sprintf "at %.2fM", $p->{size} / 1024 ** 2;
             printf _p_fmt( $opt, "start" ), $video_count, $retries, $at;
-            open my $fh, '>>:raw', encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!";
+            open my $fh, '>>:raw', encode_fs( $opt, $file_name ) or die encode_fs( $opt, $file_name ) . " $!";
             $res = $ua->get(
                 $video_url,
                 'Range'       => "bytes=$p->{size}-",
@@ -131,7 +131,7 @@ sub _status {
     print up;
     print cldown;
     if ( $status =~ /^(200|206|416)/ ) {
-        my $file_size = -s encode_fs( $file_name ) // -1;
+        my $file_size = -s encode_fs( $opt, $file_name ) // -1;
         $avg_speed = sprintf "avg %2sk/s", $p->{kbs_avg} || '--';
         if ( $p->{total} ) {
             my $len_total_mb = length( int( $p->{total} / 1024 ** 2 ) ) + 2;
@@ -274,7 +274,7 @@ sub _log_info {
         . ' | ' . ( length $playlist_id ? $playlist_id : '-----' )
         . ' | ' . ( $info->{$ex}{$video_id}{upload_date} )
         . '   ' . basename( $info->{$ex}{$video_id}{file_name}{$fmt} );
-    open my $log, '>>:encoding(UTF-8)', encode_fs( $opt->{log_file} ) or die $!;
+    open my $log, '>>:encoding(UTF-8)', encode_fs( $opt, $opt->{log_file} ) or die $!;
     flock $log, LOCK_EX     or die $!;
     seek  $log, 0, SEEK_END or die $!;
     say   $log $log_str;
