@@ -64,9 +64,9 @@ sub search_and_merge {
                     $first_line_out = '';
                 }
                 my $video_dir = $info->{$ex}{$video_id}{video_dir};
-                my $file_name = get_filename( $opt, $info->{$ex}{$video_id}{title}, $opt->{merge_ext}, $height );
+                my $file_name = get_filename( $opt, $info->{$ex}{$video_id}{title_filename}, $opt->{merge_ext}, $height );
                 my $out = catfile $video_dir, $file_name;
-                if ( -f $out && ! $opt->{merge_overwrite} ) {
+                if ( -f encode_fs( $opt, $out ) && ! $opt->{merge_overwrite} ) {
                     my $overwrite_ok = choose(
                         [ '  Skip', '  Overwrite' ],
                         { prompt => 'Already exists: ' . $file_name, layout => 3, index => 1 } #
@@ -78,15 +78,15 @@ sub search_and_merge {
                     say ' ' .  check_mapping_stdout( $opt, $out );
                     if ( $opt->{merged_in_files} == 1 ) {
                         my $dir_orig_files = catdir $video_dir, $opt->{dir_stream_files};
-                        make_path encode_fs( $dir_orig_files );
-                        move encode_fs( $video ), encode_fs( $dir_orig_files ) or die check_mapping_stdout( $opt, $video ) . " $!";
-                        move encode_fs( $audio ), encode_fs( $dir_orig_files ) or die check_mapping_stdout( $opt, $audio ) . " $!";
+                        make_path encode_fs( $opt, $dir_orig_files );
+                        move encode_fs( $opt, $video ), encode_fs( $opt, $dir_orig_files ) or die encode_fs( $opt, $video ) . " $!";
+                        move encode_fs( $opt, $audio ), encode_fs( $opt, $dir_orig_files ) or die encode_fs( $opt, $audio ) . " $!";
                     }
                     elsif ( $opt->{merged_in_files} == 2 ) {
-                        unlink encode_fs( $video ) or die check_mapping_stdout( $opt, $video ) . " $!";
-                        unlink encode_fs( $audio ) or die check_mapping_stdout( $opt, $audio ) . " $!";
+                        unlink encode_fs( $opt, $video ) or die encode_fs( $opt, $video ) . " $!";
+                        unlink encode_fs( $opt, $audio ) or die encode_fs( $opt, $audio ) . " $!";
                     }
-                    timestamp_to_upload_date( $info, $ex, $video_id, $out ) if $opt->{modify_timestamp};
+                    timestamp_to_upload_date( $opt, $info, $ex, $video_id, $out ) if $opt->{modify_timestamp};
                 }
                 catch {
                     say "$video_id - Merge: ", check_mapping_stdout( $opt, $_ );
@@ -103,12 +103,12 @@ sub _merge_video_with_audio {
     my @cmd = ( $opt->{ffmpeg} );
     push @cmd, '-loglevel', $opt->{merge_loglevel};
     push @cmd, '-y';
-    push @cmd, '-i', encode_fs( $video );
-    push @cmd, '-i', encode_fs( $audio );
+    push @cmd, '-i', encode_fs( $opt, $video );
+    push @cmd, '-i', encode_fs( $opt, $audio );
     push @cmd, '-codec', 'copy';
     push @cmd, '-map', '0:v:0';
     push @cmd, '-map', '1:a:0';
-    push @cmd, encode_fs( $out );
+    push @cmd, encode_fs( $opt, $out );
     uni_system( @cmd );
 }
 
@@ -118,7 +118,7 @@ sub _get_stream_info {
     my @cmd = ( $opt->{ffprobe} );
     push @cmd, '-loglevel', 'warning';
     push @cmd, '-show_streams';
-    push @cmd, encode_fs( $file );
+    push @cmd, encode_fs( $opt, $file );
     my $stream_info = uni_capture( @cmd );
     return $stream_info;
 }
