@@ -100,10 +100,11 @@ sub _menus {
             [ 'uploader_dir',  "- Uploader directory"   ],
         ],
         group_file => [
-            [ 'max_len_f_name',    "- Max filename length" ],
-            [ 'replace_spaces',    "- Replace spaces"      ],
-            [ 'sanitize_filename', "- Sanitize filename"   ],
-            [ 'modify_timestamp',  "- File timestamp"      ],
+            [ 'max_len_f_name',      "- Max filename length" ],
+            [ 'replace_spaces',      "- Replace spaces"      ],
+            [ 'sanitize_filename',   "- Sanitize filename"   ],
+            [ 'unmappable_filename', "- Encode filename"     ],
+            [ 'modify_timestamp',    "- File timestamp"      ],
         ],
         group_quality => [
             [ 'auto_quality',     "- Auto quality mode"            ],
@@ -136,9 +137,9 @@ sub _menus {
             [ 'show_view_count', "- Show view count" ],
         ],
         group_output => [
-            [ 'text_unidecode', "- Unmappable characters" ],
-            [ 'max_info_width', "- Max info width"        ],
-            [ 'kb_sec_len',     "- Digits 'k/s'"          ],
+            [ 'text_unidecode', "- Unmappable infotext" ],
+            [ 'max_info_width', "- Max info width"    ],
+            [ 'kb_sec_len',     "- Digits 'k/s'"      ],
         ],
         group_youtube_dl => [
             [ 'use_netrc',         "- Use '.netrc'" ],
@@ -295,6 +296,15 @@ sub set_options {
                 my $list = [
                     'keep all',
                     'replace  / \ : " * ? < > | &',
+                    'replace  /',
+                ];
+                _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
+            }
+            elsif ( $choice eq "unmappable_filename" ) {
+                my $prompt = 'Filename not mappable to file system encoding';
+                my $list = [
+                    'don\'t encode',
+                    'use Text::Unidecode',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
@@ -435,7 +445,7 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "text_unidecode" ) {
-                my $prompt = 'Unmappable characters';
+                my $prompt = 'Characters not mappable to console out';
                 my $list = [
                     'replace with *',
                     'use Text::Unidecode',
